@@ -2,13 +2,13 @@ import pandas as pd
 import numpy as np
 
 import copy
-import viz
 import os
 
 from . import actual_modelling
 from . import prep
 from . import misc
 from . import calculus
+from . import viz
 
 ALPHABET="ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 
